@@ -1,4 +1,4 @@
-# Copyright 2016 Google Inc.
+# Copyright 2016 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,10 @@
 
 
 from pkg_resources import get_distribution
-__version__ = get_distribution('google-cloud-translate').version
+
+__version__ = get_distribution("google-cloud-translate").version
 
 from google.cloud.translate_v2.client import Client
 
 
-__all__ = (
-    '__version__',
-    'Client',
-)
+__all__ = ("__version__", "Client")
