@@ -81,8 +81,14 @@ class TranslateTextGlossaryConfig(proto.Message):
             missing.
     """
 
-    glossary = proto.Field(proto.STRING, number=1,)
-    ignore_case = proto.Field(proto.BOOL, number=2,)
+    glossary = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    ignore_case = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
 
 
 class TranslateTextRequest(proto.Message):
@@ -150,7 +156,7 @@ class TranslateTextRequest(proto.Message):
             within the same region (have the same location-id) as the
             model, otherwise an INVALID_ARGUMENT (400) error is
             returned.
-        labels (Sequence[google.cloud.translate_v3.types.TranslateTextRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. The labels with user-defined
             metadata for the request.
             Label keys and values can be no longer than 63
@@ -164,16 +170,40 @@ class TranslateTextRequest(proto.Message):
             for more information.
     """
 
-    contents = proto.RepeatedField(proto.STRING, number=1,)
-    mime_type = proto.Field(proto.STRING, number=3,)
-    source_language_code = proto.Field(proto.STRING, number=4,)
-    target_language_code = proto.Field(proto.STRING, number=5,)
-    parent = proto.Field(proto.STRING, number=8,)
-    model = proto.Field(proto.STRING, number=6,)
+    contents = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    source_language_code = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    target_language_code = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     glossary_config = proto.Field(
-        proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
+        proto.MESSAGE,
+        number=7,
+        message="TranslateTextGlossaryConfig",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=10,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
 
 
 class TranslateTextResponse(proto.Message):
@@ -192,9 +222,15 @@ class TranslateTextResponse(proto.Message):
             [``contents``][google.cloud.translation.v3.TranslateTextRequest.contents].
     """
 
-    translations = proto.RepeatedField(proto.MESSAGE, number=1, message="Translation",)
+    translations = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Translation",
+    )
     glossary_translations = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="Translation",
+        proto.MESSAGE,
+        number=3,
+        message="Translation",
     )
 
 
@@ -226,11 +262,22 @@ class Translation(proto.Message):
             The ``glossary_config`` used for this translation.
     """
 
-    translated_text = proto.Field(proto.STRING, number=1,)
-    model = proto.Field(proto.STRING, number=2,)
-    detected_language_code = proto.Field(proto.STRING, number=4,)
+    translated_text = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    detected_language_code = proto.Field(
+        proto.STRING,
+        number=4,
+    )
     glossary_config = proto.Field(
-        proto.MESSAGE, number=3, message="TranslateTextGlossaryConfig",
+        proto.MESSAGE,
+        number=3,
+        message="TranslateTextGlossaryConfig",
     )
 
 
@@ -273,7 +320,7 @@ class DetectLanguageRequest(proto.Message):
             Optional. The format of the source text, for
             example, "text/html", "text/plain". If left
             blank, the MIME type defaults to "text/html".
-        labels (Sequence[google.cloud.translate_v3.types.DetectLanguageRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. The labels with user-defined
             metadata for the request.
             Label keys and values can be no longer than 63
@@ -287,11 +334,28 @@ class DetectLanguageRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=5,)
-    model = proto.Field(proto.STRING, number=4,)
-    content = proto.Field(proto.STRING, number=1, oneof="source",)
-    mime_type = proto.Field(proto.STRING, number=3,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=6,)
+    parent = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    content = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="source",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
+    )
 
 
 class DetectedLanguage(proto.Message):
@@ -306,8 +370,14 @@ class DetectedLanguage(proto.Message):
             this language.
     """
 
-    language_code = proto.Field(proto.STRING, number=1,)
-    confidence = proto.Field(proto.FLOAT, number=2,)
+    language_code = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    confidence = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 class DetectLanguageResponse(proto.Message):
@@ -322,7 +392,9 @@ class DetectLanguageResponse(proto.Message):
     """
 
     languages = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="DetectedLanguage",
+        proto.MESSAGE,
+        number=1,
+        message="DetectedLanguage",
     )
 
 
@@ -367,9 +439,18 @@ class GetSupportedLanguagesRequest(proto.Message):
             model.
     """
 
-    parent = proto.Field(proto.STRING, number=3,)
-    display_language_code = proto.Field(proto.STRING, number=1,)
-    model = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    display_language_code = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class SupportedLanguages(proto.Message):
@@ -383,7 +464,9 @@ class SupportedLanguages(proto.Message):
     """
 
     languages = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="SupportedLanguage",
+        proto.MESSAGE,
+        number=1,
+        message="SupportedLanguage",
     )
 
 
@@ -408,10 +491,22 @@ class SupportedLanguage(proto.Message):
             Can be used as target language.
     """
 
-    language_code = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    support_source = proto.Field(proto.BOOL, number=3,)
-    support_target = proto.Field(proto.BOOL, number=4,)
+    language_code = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    support_source = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+    support_target = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
 class GcsSource(proto.Message):
@@ -423,7 +518,10 @@ class GcsSource(proto.Message):
             ``gs://my_bucket/my_object``.
     """
 
-    input_uri = proto.Field(proto.STRING, number=1,)
+    input_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class InputConfig(proto.Message):
@@ -461,9 +559,15 @@ class InputConfig(proto.Message):
             This field is a member of `oneof`_ ``source``.
     """
 
-    mime_type = proto.Field(proto.STRING, number=1,)
+    mime_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     gcs_source = proto.Field(
-        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=2,
+        oneof="source",
+        message="GcsSource",
     )
 
 
@@ -480,7 +584,10 @@ class GcsDestination(proto.Message):
             INVALID_ARGUMENT (400) error is returned.
     """
 
-    output_uri_prefix = proto.Field(proto.STRING, number=1,)
+    output_uri_prefix = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class OutputConfig(proto.Message):
@@ -571,7 +678,10 @@ class OutputConfig(proto.Message):
     """
 
     gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
     )
 
 
@@ -610,11 +720,21 @@ class DocumentInputConfig(proto.Message):
             -  application/vnd.openxmlformats-officedocument.spreadsheetml.sheet
     """
 
-    content = proto.Field(proto.BYTES, number=1, oneof="source",)
+    content = proto.Field(
+        proto.BYTES,
+        number=1,
+        oneof="source",
+    )
     gcs_source = proto.Field(
-        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=2,
+        oneof="source",
+        message="GcsSource",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    mime_type = proto.Field(proto.STRING, number=4,)
 
 
 class DocumentOutputConfig(proto.Message):
@@ -688,9 +808,15 @@ class DocumentOutputConfig(proto.Message):
     """
 
     gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    mime_type = proto.Field(proto.STRING, number=3,)
 
 
 class TranslateDocumentRequest(proto.Message):
@@ -755,7 +881,7 @@ class TranslateDocumentRequest(proto.Message):
             within the same region (have the same location-id) as the
             model, otherwise an INVALID_ARGUMENT (400) error is
             returned.
-        labels (Sequence[google.cloud.translate_v3.types.TranslateDocumentRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. The labels with user-defined
             metadata for the request.
             Label keys and values can be no longer than 63
@@ -769,20 +895,42 @@ class TranslateDocumentRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    source_language_code = proto.Field(proto.STRING, number=2,)
-    target_language_code = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    source_language_code = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_language_code = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     document_input_config = proto.Field(
-        proto.MESSAGE, number=4, message="DocumentInputConfig",
+        proto.MESSAGE,
+        number=4,
+        message="DocumentInputConfig",
     )
     document_output_config = proto.Field(
-        proto.MESSAGE, number=5, message="DocumentOutputConfig",
+        proto.MESSAGE,
+        number=5,
+        message="DocumentOutputConfig",
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    model = proto.Field(proto.STRING, number=6,)
     glossary_config = proto.Field(
-        proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
+        proto.MESSAGE,
+        number=7,
+        message="TranslateTextGlossaryConfig",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=8,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=8,)
 
 
 class DocumentTranslation(proto.Message):
@@ -806,9 +954,18 @@ class DocumentTranslation(proto.Message):
             empty.
     """
 
-    byte_stream_outputs = proto.RepeatedField(proto.BYTES, number=1,)
-    mime_type = proto.Field(proto.STRING, number=2,)
-    detected_language_code = proto.Field(proto.STRING, number=3,)
+    byte_stream_outputs = proto.RepeatedField(
+        proto.BYTES,
+        number=1,
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    detected_language_code = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class TranslateDocumentResponse(proto.Message):
@@ -836,14 +993,23 @@ class TranslateDocumentResponse(proto.Message):
     """
 
     document_translation = proto.Field(
-        proto.MESSAGE, number=1, message="DocumentTranslation",
+        proto.MESSAGE,
+        number=1,
+        message="DocumentTranslation",
     )
     glossary_document_translation = proto.Field(
-        proto.MESSAGE, number=2, message="DocumentTranslation",
+        proto.MESSAGE,
+        number=2,
+        message="DocumentTranslation",
+    )
+    model = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    model = proto.Field(proto.STRING, number=3,)
     glossary_config = proto.Field(
-        proto.MESSAGE, number=4, message="TranslateTextGlossaryConfig",
+        proto.MESSAGE,
+        number=4,
+        message="TranslateTextGlossaryConfig",
     )
 
 
@@ -869,7 +1035,7 @@ class BatchTranslateTextRequest(proto.Message):
         target_language_codes (Sequence[str]):
             Required. Specify up to 10 language codes
             here.
-        models (Sequence[google.cloud.translate_v3.types.BatchTranslateTextRequest.ModelsEntry]):
+        models (Mapping[str, str]):
             Optional. The models to use for translation. Map's key is
             target language code. Map's value is model name. Value can
             be a built-in general model, or an AutoML Translation model.
@@ -895,10 +1061,10 @@ class BatchTranslateTextRequest(proto.Message):
             If 2 input configs match to the same file (that
             is, same input path), we don't generate output
             for duplicate inputs.
-        glossaries (Sequence[google.cloud.translate_v3.types.BatchTranslateTextRequest.GlossariesEntry]):
+        glossaries (Mapping[str, google.cloud.translate_v3.types.TranslateTextGlossaryConfig]):
             Optional. Glossaries to be applied for
             translation. It's keyed by target language code.
-        labels (Sequence[google.cloud.translate_v3.types.BatchTranslateTextRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. The labels with user-defined
             metadata for the request.
             Label keys and values can be no longer than 63
@@ -912,16 +1078,44 @@ class BatchTranslateTextRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    source_language_code = proto.Field(proto.STRING, number=2,)
-    target_language_codes = proto.RepeatedField(proto.STRING, number=3,)
-    models = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    input_configs = proto.RepeatedField(proto.MESSAGE, number=5, message="InputConfig",)
-    output_config = proto.Field(proto.MESSAGE, number=6, message="OutputConfig",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    source_language_code = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_language_codes = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    models = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    input_configs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="InputConfig",
+    )
+    output_config = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="OutputConfig",
+    )
     glossaries = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
+        proto.STRING,
+        proto.MESSAGE,
+        number=7,
+        message="TranslateTextGlossaryConfig",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=9,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=9,)
 
 
 class BatchTranslateMetadata(proto.Message):
@@ -955,11 +1149,28 @@ class BatchTranslateMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    translated_characters = proto.Field(proto.INT64, number=2,)
-    failed_characters = proto.Field(proto.INT64, number=3,)
-    total_characters = proto.Field(proto.INT64, number=4,)
-    submit_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    translated_characters = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    failed_characters = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    total_characters = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class BatchTranslateResponse(proto.Message):
@@ -986,11 +1197,28 @@ class BatchTranslateResponse(proto.Message):
             is set to true.
     """
 
-    total_characters = proto.Field(proto.INT64, number=1,)
-    translated_characters = proto.Field(proto.INT64, number=2,)
-    failed_characters = proto.Field(proto.INT64, number=3,)
-    submit_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
+    total_characters = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    translated_characters = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    failed_characters = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class GlossaryInputConfig(proto.Message):
@@ -1029,7 +1257,10 @@ class GlossaryInputConfig(proto.Message):
     """
 
     gcs_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="GcsSource",
     )
 
 
@@ -1084,8 +1315,14 @@ class Glossary(proto.Message):
                 GlossaryTerm.language_code.
         """
 
-        source_language_code = proto.Field(proto.STRING, number=1,)
-        target_language_code = proto.Field(proto.STRING, number=2,)
+        source_language_code = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        target_language_code = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class LanguageCodesSet(proto.Message):
         r"""Used with equivalent term set glossaries.
@@ -1098,19 +1335,46 @@ class Glossary(proto.Message):
                 GlossaryTerm.language_code.
         """
 
-        language_codes = proto.RepeatedField(proto.STRING, number=1,)
+        language_codes = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     language_pair = proto.Field(
-        proto.MESSAGE, number=3, oneof="languages", message=LanguageCodePair,
+        proto.MESSAGE,
+        number=3,
+        oneof="languages",
+        message=LanguageCodePair,
     )
     language_codes_set = proto.Field(
-        proto.MESSAGE, number=4, oneof="languages", message=LanguageCodesSet,
+        proto.MESSAGE,
+        number=4,
+        oneof="languages",
+        message=LanguageCodesSet,
+    )
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="GlossaryInputConfig",
+    )
+    entry_count = proto.Field(
+        proto.INT32,
+        number=6,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
     )
-    input_config = proto.Field(proto.MESSAGE, number=5, message="GlossaryInputConfig",)
-    entry_count = proto.Field(proto.INT32, number=6,)
-    submit_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
 
 
 class CreateGlossaryRequest(proto.Message):
@@ -1123,8 +1387,15 @@ class CreateGlossaryRequest(proto.Message):
             Required. The glossary to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    glossary = proto.Field(proto.MESSAGE, number=2, message="Glossary",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    glossary = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Glossary",
+    )
 
 
 class GetGlossaryRequest(proto.Message):
@@ -1136,7 +1407,10 @@ class GetGlossaryRequest(proto.Message):
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteGlossaryRequest(proto.Message):
@@ -1147,7 +1421,10 @@ class DeleteGlossaryRequest(proto.Message):
             Required. The name of the glossary to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListGlossariesRequest(proto.Message):
@@ -1195,10 +1472,22 @@ class ListGlossariesRequest(proto.Message):
             performed.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListGlossariesResponse(proto.Message):
@@ -1218,8 +1507,15 @@ class ListGlossariesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    glossaries = proto.RepeatedField(proto.MESSAGE, number=1, message="Glossary",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    glossaries = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Glossary",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CreateGlossaryMetadata(proto.Message):
@@ -1250,9 +1546,20 @@ class CreateGlossaryMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    name = proto.Field(proto.STRING, number=1,)
-    state = proto.Field(proto.ENUM, number=2, enum=State,)
-    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=State,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class DeleteGlossaryMetadata(proto.Message):
@@ -1283,9 +1590,20 @@ class DeleteGlossaryMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    name = proto.Field(proto.STRING, number=1,)
-    state = proto.Field(proto.ENUM, number=2, enum=State,)
-    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=State,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class DeleteGlossaryResponse(proto.Message):
@@ -1305,9 +1623,20 @@ class DeleteGlossaryResponse(proto.Message):
             is set to true.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class BatchTranslateDocumentRequest(proto.Message):
@@ -1347,7 +1676,7 @@ class BatchTranslateDocumentRequest(proto.Message):
             If 2 input configs match to the same file (that
             is, same input path), we don't generate output
             for duplicate inputs.
-        models (Sequence[google.cloud.translate_v3.types.BatchTranslateDocumentRequest.ModelsEntry]):
+        models (Mapping[str, str]):
             Optional. The models to use for translation. Map's key is
             target language code. Map's value is the model name. Value
             can be a built-in general model, or an AutoML Translation
@@ -1363,10 +1692,10 @@ class BatchTranslateDocumentRequest(proto.Message):
 
             If the map is empty or a specific model is not requested for
             a language pair, then default google model (nmt) is used.
-        glossaries (Sequence[google.cloud.translate_v3.types.BatchTranslateDocumentRequest.GlossariesEntry]):
+        glossaries (Mapping[str, google.cloud.translate_v3.types.TranslateTextGlossaryConfig]):
             Optional. Glossaries to be applied. It's
             keyed by target language code.
-        format_conversions (Sequence[google.cloud.translate_v3.types.BatchTranslateDocumentRequest.FormatConversionsEntry]):
+        format_conversions (Mapping[str, str]):
             Optional. File format conversion map to be applied to all
             input files. Map's key is the original mime_type. Map's
             value is the target mime_type of translated documents.
@@ -1380,20 +1709,44 @@ class BatchTranslateDocumentRequest(proto.Message):
             format as the original file.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    source_language_code = proto.Field(proto.STRING, number=2,)
-    target_language_codes = proto.RepeatedField(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    source_language_code = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_language_codes = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
     input_configs = proto.RepeatedField(
-        proto.MESSAGE, number=4, message="BatchDocumentInputConfig",
+        proto.MESSAGE,
+        number=4,
+        message="BatchDocumentInputConfig",
     )
     output_config = proto.Field(
-        proto.MESSAGE, number=5, message="BatchDocumentOutputConfig",
+        proto.MESSAGE,
+        number=5,
+        message="BatchDocumentOutputConfig",
+    )
+    models = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
     )
-    models = proto.MapField(proto.STRING, proto.STRING, number=6,)
     glossaries = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
+        proto.STRING,
+        proto.MESSAGE,
+        number=7,
+        message="TranslateTextGlossaryConfig",
+    )
+    format_conversions = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=8,
     )
-    format_conversions = proto.MapField(proto.STRING, proto.STRING, number=8,)
 
 
 class BatchDocumentInputConfig(proto.Message):
@@ -1428,7 +1781,10 @@ class BatchDocumentInputConfig(proto.Message):
     """
 
     gcs_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="GcsSource",
     )
 
 
@@ -1496,7 +1852,10 @@ class BatchDocumentOutputConfig(proto.Message):
     """
 
     gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
     )
 
 
@@ -1543,16 +1902,48 @@ class BatchTranslateDocumentResponse(proto.Message):
             is set to true.
     """
 
-    total_pages = proto.Field(proto.INT64, number=1,)
-    translated_pages = proto.Field(proto.INT64, number=2,)
-    failed_pages = proto.Field(proto.INT64, number=3,)
-    total_billable_pages = proto.Field(proto.INT64, number=4,)
-    total_characters = proto.Field(proto.INT64, number=5,)
-    translated_characters = proto.Field(proto.INT64, number=6,)
-    failed_characters = proto.Field(proto.INT64, number=7,)
-    total_billable_characters = proto.Field(proto.INT64, number=8,)
-    submit_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,)
+    total_pages = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    translated_pages = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    failed_pages = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    total_billable_pages = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    total_characters = proto.Field(
+        proto.INT64,
+        number=5,
+    )
+    translated_characters = proto.Field(
+        proto.INT64,
+        number=6,
+    )
+    failed_characters = proto.Field(
+        proto.INT64,
+        number=7,
+    )
+    total_billable_characters = proto.Field(
+        proto.INT64,
+        number=8,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class BatchTranslateDocumentMetadata(proto.Message):
@@ -1604,17 +1995,47 @@ class BatchTranslateDocumentMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    total_pages = proto.Field(proto.INT64, number=2,)
-    translated_pages = proto.Field(proto.INT64, number=3,)
-    failed_pages = proto.Field(proto.INT64, number=4,)
-    total_billable_pages = proto.Field(proto.INT64, number=5,)
-    total_characters = proto.Field(proto.INT64, number=6,)
-    translated_characters = proto.Field(proto.INT64, number=7,)
-    failed_characters = proto.Field(proto.INT64, number=8,)
-    total_billable_characters = proto.Field(proto.INT64, number=9,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    total_pages = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    translated_pages = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    failed_pages = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    total_billable_pages = proto.Field(
+        proto.INT64,
+        number=5,
+    )
+    total_characters = proto.Field(
+        proto.INT64,
+        number=6,
+    )
+    translated_characters = proto.Field(
+        proto.INT64,
+        number=7,
+    )
+    failed_characters = proto.Field(
+        proto.INT64,
+        number=8,
+    )
+    total_billable_characters = proto.Field(
+        proto.INT64,
+        number=9,
+    )
     submit_time = proto.Field(
-        proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=10,
+        message=timestamp_pb2.Timestamp,
     )
 
 
