@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -59,7 +59,8 @@ class TranslationServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = TranslationServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[TranslationServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -165,10 +166,16 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def glossary_path(project: str, location: str, glossary: str,) -> str:
+    def glossary_path(
+        project: str,
+        location: str,
+        glossary: str,
+    ) -> str:
         """Returns a fully-qualified glossary string."""
         return "projects/{project}/locations/{location}/glossaries/{glossary}".format(
-            project=project, location=location, glossary=glossary,
+            project=project,
+            location=location,
+            glossary=glossary,
         )
 
     @staticmethod
@@ -181,7 +188,9 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -194,9 +203,13 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -205,9 +218,13 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -216,9 +233,13 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -227,10 +248,14 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -468,7 +493,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -601,7 +631,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -620,7 +655,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Returns a list of supported languages for
         translation.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -740,7 +774,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -813,7 +852,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -836,7 +880,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         use google.longrunning.Operation.name to poll the status
         of the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -908,7 +951,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -944,7 +992,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         google.longrunning.Operation.name to poll the status of
         the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -1102,7 +1149,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1128,7 +1180,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Creates a glossary and returns the long-running operation.
         Returns NOT_FOUND, if the project doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -1218,7 +1269,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1244,7 +1300,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -1358,12 +1413,20 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListGlossariesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1381,7 +1444,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
         exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -1455,7 +1517,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1473,7 +1540,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         glossary isn't created yet. Returns NOT_FOUND, if the glossary
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
@@ -1554,7 +1620,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1583,7 +1654,9 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-translate",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-translate",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
